greenheart.tools.optimization.mpi\_tools
========================================

.. automodule:: greenheart.tools.optimization.mpi_tools

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      map_comm_heirarchical
      subprocessor_loop
      subprocessor_stop
      under_mpirun
   
   

   
   
   

   
   
   



